@@ -1,11 +1,11 @@
 use crate::{
-    interpret_trait::{InterpretableFrom, InterpreterContext},
+    interpret_trait::{InterpretableFrom, InterpreterContext, IntoRaw},
     serde_raw::BlockInfoRaw,
 };
 
 use super::{BytesValue, U64Value};
 
-#[derive(Debug)]
+#[derive(Debug, Default)]
 pub struct BlockInfo {
     pub block_timestamp: Option<U64Value>,
     pub block_nonce: Option<U64Value>,
@@ -35,3 +35,15 @@ impl InterpretableFrom<BlockInfoRaw> for BlockInfo {
         }
     }
 }
+
+impl IntoRaw<BlockInfoRaw> for BlockInfo {
+    fn into_raw(self) -> BlockInfoRaw {
+        BlockInfoRaw {
+            block_timestamp: self.block_timestamp.map(|value| value.original),
+            block_nonce: self.block_nonce.map(|value| value.original),
+            block_round: self.block_round.map(|value| value.original),
+            block_epoch: self.block_epoch.map(|value| value.original),
+            block_random_seed: self.block_random_seed.map(|value| value.original),
+        }
+    }
+}
