@@ -1,5 +1,5 @@
 use crate::{
-    interpret_trait::{InterpretableFrom, InterpreterContext},
+    interpret_trait::{InterpretableFrom, InterpreterContext, IntoRaw},
     model::{CheckValue, U64Value},
     serde_raw::CheckEsdtDataRaw,
 };
@@ -22,3 +22,14 @@ impl InterpretableFrom<CheckEsdtDataRaw> for CheckEsdtData {
         }
     }
 }
+
+impl IntoRaw<CheckEsdtDataRaw> for CheckEsdtData {
+    fn into_raw(self) -> CheckEsdtDataRaw {
+        CheckEsdtDataRaw {
+            instances: self.instances.into_raw(),
+            last_nonce: self.last_nonce.into_raw(),
+            roles: Vec::new(),
+            frozen: self.frozen.into_raw(),
+        }
+    }
+}
