@@ -1,5 +1,5 @@
 use crate::{
-    interpret_trait::{InterpretableFrom, InterpreterContext},
+    interpret_trait::{InterpretableFrom, InterpreterContext, IntoRaw},
     serde_raw::NewAddressRaw,
 };
 
@@ -21,3 +21,13 @@ impl InterpretableFrom<NewAddressRaw> for NewAddress {
         }
     }
 }
+
+impl IntoRaw<NewAddressRaw> for NewAddress {
+    fn into_raw(self) -> NewAddressRaw {
+        NewAddressRaw {
+            creator_address: self.creator_address.original,
+            creator_nonce: self.creator_nonce.original,
+            new_address: self.new_address.original,
+        }
+    }
+}
