@@ -1,5 +1,5 @@
 use crate::{
-    interpret_trait::{InterpretableFrom, InterpreterContext},
+    interpret_trait::{InterpretableFrom, InterpreterContext, IntoRaw},
     model::{BytesValue, CheckValue},
     serde_raw::CheckStorageDetailsRaw,
 };
@@ -8,7 +8,7 @@ use std::collections::BTreeMap;
 
 use super::BytesKey;
 
-#[derive(Debug)]
+#[derive(Debug, Default)]
 pub struct CheckStorageDetails {
     pub storages: BTreeMap<BytesKey, CheckValue<BytesValue>>,
     pub other_storages_allowed: bool,
@@ -31,3 +31,16 @@ impl InterpretableFrom<CheckStorageDetailsRaw> for CheckStorageDetails {
         }
     }
 }
+
+impl IntoRaw<CheckStorageDetailsRaw> for CheckStorageDetails {
+    fn into_raw(self) -> CheckStorageDetailsRaw {
+        CheckStorageDetailsRaw {
+            storages: self
+                .storages
+                .into_iter()
+                .map(|(k, v)| (k.into_raw(), v.into_raw_explicit()))
+                .collect(),
+            other_storages_allowed: self.other_storages_allowed,
+        }
+    }
+}
