@@ -1,5 +1,5 @@
 use crate::{
-    interpret_trait::{InterpretableFrom, InterpreterContext},
+    interpret_trait::{InterpretableFrom, InterpreterContext, IntoRaw},
     model::{BytesValue, CheckValue, CheckValueList},
     serde_raw::CheckLogRaw,
 };
@@ -22,3 +22,14 @@ impl InterpretableFrom<CheckLogRaw> for CheckLog {
         }
     }
 }
+
+impl IntoRaw<CheckLogRaw> for CheckLog {
+    fn into_raw(self) -> CheckLogRaw {
+        CheckLogRaw {
+            address: self.address.into_raw(),
+            endpoint: self.endpoint.into_raw(),
+            topics: self.topics.into_raw(),
+            data: self.data.into_raw(),
+        }
+    }
+}
