@@ -1,5 +1,5 @@
 use crate::{
-    interpret_trait::{InterpretableFrom, InterpreterContext},
+    interpret_trait::{InterpretableFrom, InterpreterContext, IntoRaw},
     serde_raw::{CheckLogListRaw, CheckLogsRaw},
 };
 
@@ -24,6 +24,15 @@ impl InterpretableFrom<CheckLogListRaw> for CheckLogList {
     }
 }
 
+impl IntoRaw<CheckLogListRaw> for CheckLogList {
+    fn into_raw(self) -> CheckLogListRaw {
+        CheckLogListRaw {
+            list: self.list.into_iter().map(|c| c.into_raw()).collect(),
+            more_allowed_at_end: self.more_allowed_at_end,
+        }
+    }
+}
+
 #[derive(Debug)]
 pub enum CheckLogs {
     Star,
@@ -45,3 +54,12 @@ impl InterpretableFrom<CheckLogsRaw> for CheckLogs {
         }
     }
 }
+
+impl IntoRaw<CheckLogsRaw> for CheckLogs {
+    fn into_raw(self) -> CheckLogsRaw {
+        match self {
+            CheckLogs::Star => CheckLogsRaw::Unspecified,
+            CheckLogs::List(l) => CheckLogsRaw::List(l.into_raw()),
+        }
+    }
+}
