@@ -1,5 +1,5 @@
 use crate::{
-    interpret_trait::{InterpretableFrom, InterpreterContext},
+    interpret_trait::{InterpretableFrom, InterpreterContext, IntoRaw},
     model::{BigUintValue, BytesValue, U64Value},
     serde_raw::{TxESDTRaw, ValueSubTree},
 };
@@ -21,6 +21,16 @@ impl InterpretableFrom<TxESDTRaw> for TxESDT {
     }
 }
 
+impl IntoRaw<TxESDTRaw> for TxESDT {
+    fn into_raw(self) -> TxESDTRaw {
+        TxESDTRaw {
+            token_identifier: Some(self.esdt_token_identifier.into_raw()),
+            nonce: self.nonce.into_raw_opt(),
+            value: self.esdt_value.into_raw(),
+        }
+    }
+}
+
 fn interpret_esdt_token_identifier(
     esdt_token_identifier: Option<ValueSubTree>,
     context: &InterpreterContext,
