@@ -1,5 +1,5 @@
 use crate::{
-    interpret_trait::{InterpretableFrom, InterpreterContext},
+    interpret_trait::{InterpretableFrom, InterpreterContext, IntoRaw},
     model::{AddressValue, BigUintValue},
     serde_raw::TxValidatorRewardRaw,
 };
@@ -20,3 +20,13 @@ impl InterpretableFrom<TxValidatorRewardRaw> for TxValidatorReward {
         }
     }
 }
+
+impl IntoRaw<TxValidatorRewardRaw> for TxValidatorReward {
+    fn into_raw(self) -> TxValidatorRewardRaw {
+        TxValidatorRewardRaw {
+            to: self.to.into_raw(),
+            value: None,
+            egld_value: Some(self.egld_value.into_raw()),
+        }
+    }
+}
