@@ -1,4 +1,4 @@
-mod address;
+mod address_key;
 mod address_value;
 mod value_check;
 mod value_checkable;
@@ -8,7 +8,7 @@ mod value_set_big_uint;
 mod value_set_bytes;
 mod value_set_u64;
 
-pub use address::*;
+pub use address_key::*;
 pub use address_value::*;
 pub use value_check::*;
 pub use value_checkable::*;
