@@ -1,6 +1,6 @@
 use serde::{Deserialize, Serialize};
 
-use crate::serde_raw::{CheckBytesValueRaw, ValueSubTree};
+use crate::serde_raw::{CheckBytesValueRaw, CheckValueListRaw, ValueSubTree};
 
 #[derive(Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
@@ -24,8 +24,8 @@ pub struct CheckEsdtInstanceRaw {
     pub hash: CheckBytesValueRaw,
 
     #[serde(default)]
-    #[serde(skip_serializing_if = "CheckBytesValueRaw::is_unspecified")]
-    pub uri: CheckBytesValueRaw,
+    #[serde(skip_serializing_if = "CheckValueListRaw::is_unspecified")]
+    pub uri: CheckValueListRaw,
 
     #[serde(default)]
     #[serde(skip_serializing_if = "CheckBytesValueRaw::is_unspecified")]
