@@ -9,8 +9,8 @@ pub struct CheckLogRaw {
     pub endpoint: CheckBytesValueRaw,
 
     #[serde(default)]
-    #[serde(skip_serializing_if = "Vec::is_empty")]
-    pub topics: Vec<CheckBytesValueRaw>,
+    #[serde(skip_serializing_if = "CheckValueListRaw::is_unspecified")]
+    pub topics: CheckValueListRaw,
 
     pub data: CheckBytesValueRaw,
 }
